@@ -73,7 +73,7 @@ class ActionNode(RunnerNode, ABC):
         Returns:
             Node -- Node from which ops can be called
         """
-        source, block_set = func.get('blockSetKey').split('_')
+        block_set = func.get('blockSetKey')
         args = func.get('args')
         block_key = func.get('blockKey')
         block_dict = {
