@@ -1,8 +1,7 @@
 from __future__ import annotations
 import typing
 
-from .node import Node
-from .. import get_payload_element
+from .node import Node, get_payload_element
 
 
 class InputNode(Node):
