@@ -3,6 +3,19 @@ import typing
 from abc import ABC, abstractmethod
 
 
+def get_payload_element(payload: dict, element_key: str):
+    if '.' not in element_key:
+        return payload.get(element_key, element_key)
+    else:
+        ret = payload
+        keys = element_key.split('.')
+        for key in keys:
+            ret = ret.get(key, None)
+            if ret is None:
+                return key
+        return ret
+
+
 class Node(ABC):
     """Base Class for all Nodes
 
